/*
 * @file Member ID Definition of STORAGE
 *
 * Moderator: Abby Yang
 * Group ID: 0x001f0000/0x801f0000
 */

#ifndef _CSID_STORAGE_H
#define _CSID_STORAGE_H

#include "csid_gid.h"

#define _CFG_STORAGE(x)		(CSID_GIDC_STORAGE|(x))
#define _STA_STORAGE(x)		(CSID_GIDS_STORAGE|(x))

/* Extra Definitions */

/* Configuration Items */
#define CSID_C_STORAGE_DEVNUM		_CFG_STORAGE(0x0001) //T=u8, D=16, Device number
#define CSID_C_STORAGE_IPCAMNUM		_CFG_STORAGE(0x0002) //T=u8, D=16, IPCam number in each NVR

//Storage Setting
#define CSID_C_STORAGE_DEVICENAME	_CFG_STORAGE(0x0010) //T=str, D="", DeviceName
#define CSID_C_STORAGE_IP			_CFG_STORAGE(0x0020) //T=str, D="", IP
#define CSID_C_STORAGE_MAC			_CFG_STORAGE(0x0030) //T=str, D="", MAC
#define CSID_C_STORAGE_ID           _CFG_STORAGE(0x0040) //T=str, D="", ID
#define CSID_C_STORAGE_USR			_CFG_STORAGE(0x0050) //T=str, D="", Username
#define CSID_C_STORAGE_PWD			_CFG_STORAGE(0x0060) //T=str, D="", Password
#define CSID_C_STORAGE_ACTIVE		_CFG_STORAGE(0x0070) //T=str, D="", Active
#define CSID_C_STORAGE_CONFIRM		_CFG_STORAGE(0x0080) //T=u8, D=0, Storage confirm
#define CSID_C_STORAGE_AVAILABLE	_CFG_STORAGE(0x0090) //T=u8, D=1, Storage available
#define	CSID_C_STORAGE_FREENUM		_CFG_STORAGE(0x00a0) //T=u8, D=4, Free IPCam number
#define CSID_C_STORAGE_FC			_CFG_STORAGE(0x00c0) //T=u8, D=12, Storage File collector period
#define CSID_C_STORAGE_WIRELESS     _CFG_STORAGE(0x00d0) //T=u8, D=0, Storage wireless enable
#define CSID_C_STORAGE_HAVEWIRELESS _CFG_STORAGE(0x00e0) //T=u8, D=0, Storage wireless enable
#define CSID_C_STORAGE_MODELNUM	    _CFG_STORAGE(0x00f0) //T=str, D="", Model number

//Saved IPCam info of each Storage
#define CSID_C_STORAGE_N_SAVEDIPCAM_NAME	_CFG_STORAGE(0x0100) //T=str, D="", DeviceName
#define CSID_C_STORAGE_1_SAVEDIPCAM_NAME	_CFG_STORAGE(0x0110) //T=str, D="", DeviceName
#define CSID_C_STORAGE_2_SAVEDIPCAM_NAME	_CFG_STORAGE(0x0120) //T=str, D="", DeviceName
#define CSID_C_STORAGE_3_SAVEDIPCAM_NAME	_CFG_STORAGE(0x0130) //T=str, D="", DeviceName

//Samba Settings
#define CSID_C_STORAGE_SAMBA_HOSTNAME		_CFG_STORAGE(0x0200) //T=str, D="", Host Name
#define CSID_C_STORAGE_SAMBA_WORKGROUP		_CFG_STORAGE(0x0201) //T=str, D="", WorkGroup
#define CSID_C_STORAGE_SAMBA_SERVERCOMMENT	_CFG_STORAGE(0x0202) //T=str, D="", Server Comment

/* Status Items */

//HomeCom 1.0+ Register information
#define CSID_S_STORAGE_AGPINFO      _STA_STORAGE(0x0001) //T=u8,  D=1

#define CSID_S_STORAGE_REGNAME		_STA_STORAGE(0x0010) //T=str, D="", New NVR Name
#define CSID_S_STORAGE_REGIP		_STA_STORAGE(0x0020) //T=str, D="", New NVR IP
#define CSID_S_STORAGE_REGMAC		_STA_STORAGE(0x0030) //T=str, D="", New NVR MAC
#define CSID_S_STORAGE_REGCONFIRM	_STA_STORAGE(0x0040) //T=u8,  D=0
#define CSID_S_STORAGE_REGAVAILABLE	_STA_STORAGE(0x0050) //T=u8,  D=1
#define CSID_S_STORAGE_REGMODELNUM  _STA_STORAGE(0x0060) //T=str, D="", Device model number
#define CSID_S_STORAGE_REGINDEX		_STA_STORAGE(0x00a0) //T=u8,  D=-1, Status to Conf. area index
#define CSID_S_STORAGE_REGFAIL      _STA_STORAGE(0x00f0) //T=u8,  D=1

#define CSID_S_STORAGE_CAPACITY	    _STA_STORAGE(0x0110) //T=str, D="", NVR Capacity

//HomeCom 1.0+ Setting information
#define CSID_S_STORAGE_WIRELESSFAIL	_STA_STORAGE(0x0210) //T=u8, D=0, Wireless setting fail.
#define CSID_S_STORAGE_WIRELESSCHK	_STA_STORAGE(0x0220) //T=u8, D=0, Check wireless setting result.
#define CSID_S_STORAGE_WIRELESSCHANGE	_STA_STORAGE(0x0230) //T=u8, D=0, Wireless setting change.

//RT305CDS USB and BT status
//#define CSID_S_STORAGE_BT			_STA_STORAGE(0x0240) //T=u8, D=0, BT avail?.
#define CSID_S_STORAGE_USB			_STA_STORAGE(0x0240) //T=u8, D=0, USB avail? 1 avail,0 not avail
#define CSID_S_STORAGE_USB_FS		_STA_STORAGE(0x0241) //T=str, D="", USB disk file system type(N/A fat32 ntfs ext).

//Samba Status
#define CSID_S_STORAGE_SAMBA_ALTERED	_STA_STORAGE(0x0300) //T=u32, D=0, Samba Setting change alter.

//Download Assistant Status
#define CSID_S_STORAGE_DL_TYPE		_STA_STORAGE(0x0250) //T=u8, D=0, download type ,HTTP FTP
#define CSID_S_STORAGE_DL_INFO		_STA_STORAGE(0x0251) //T=str, D="", download parameter dst url
#define CSID_S_STORAGE_DL_ALTERED	_STA_STORAGE(0x0252) //T=u8, D=0, download page UI changed ,
#endif	//ifndef _CSID_STORAGE_H
